pub struct CallArgs {
pub server: String,
pub tool: String,
pub arguments: Option<Map<String, Value>>,
}Fields
server: Stringtool: Stringarguments: Option<Map<String, Value>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for CallArgs
impl<'de> Deserialize<'de> for CallArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CallArgs
impl JsonSchema for CallArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CallArgs
impl RefUnwindSafe for CallArgs
impl Send for CallArgs
impl Sync for CallArgs
impl Unpin for CallArgs
impl UnsafeUnpin for CallArgs
impl UnwindSafe for CallArgs