pub struct DescribeArgs {
pub server: String,
pub tool: String,
}Fields
server: Stringtool: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for DescribeArgs
impl<'de> Deserialize<'de> for DescribeArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DescribeArgs
impl JsonSchema for DescribeArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DescribeArgs
impl RefUnwindSafe for DescribeArgs
impl Send for DescribeArgs
impl Sync for DescribeArgs
impl Unpin for DescribeArgs
impl UnsafeUnpin for DescribeArgs
impl UnwindSafe for DescribeArgs