pub struct RefreshArgs {
pub server: Option<String>,
}Fields
server: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for RefreshArgs
impl<'de> Deserialize<'de> for RefreshArgs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RefreshArgs
impl JsonSchema for RefreshArgs
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RefreshArgs
impl RefUnwindSafe for RefreshArgs
impl Send for RefreshArgs
impl Sync for RefreshArgs
impl Unpin for RefreshArgs
impl UnsafeUnpin for RefreshArgs
impl UnwindSafe for RefreshArgs